pub struct Producer { /* private fields */ }Expand description
Produces bandwidth estimates, notifying consumers when the value changes.
Implementations
Sourceimpl Producer
impl Producer
Sourcepub fn set(&self, bitrate: Option<u64>) -> Result<()>
pub fn set(&self, bitrate: Option<u64>) -> Result<()>
Set the current bandwidth estimate in bits per second.
Sourcepub fn abort(&self, err: Error) -> Result<()>
pub fn abort(&self, err: Error) -> Result<()>
Close the producer with an error, notifying all consumers.