pub struct Consumer { /* private fields */ }Expand description
Consume a group, frame-by-frame.
Implementations
Sourceimpl Consumer
impl Consumer
Sourcepub async fn next_frame(&mut self) -> Result<Option<Consumer>>
pub async fn next_frame(&mut self) -> Result<Option<Consumer>>
Return a consumer for the next frame for chunked reading.
Sourcepub fn poll_next_frame(
&mut self,
waiter: &Waiter,
) -> Poll<Result<Option<Consumer>>>
pub fn poll_next_frame( &mut self, waiter: &Waiter, ) -> Poll<Result<Option<Consumer>>>
Poll for the next frame, without blocking.
Returns None if the group is finished and the index is out of range.
Sourcepub fn poll_read_frame(
&mut self,
waiter: &Waiter,
) -> Poll<Result<Option<Frame>>>
pub fn poll_read_frame( &mut self, waiter: &Waiter, ) -> Poll<Result<Option<Frame>>>
Read the next frame (timestamp and payload) all at once, without blocking.
Sourcepub async fn read_frame(&mut self) -> Result<Option<Frame>>
pub async fn read_frame(&mut self) -> Result<Option<Frame>>
Read the next frame (timestamp and payload) all at once.