Publishing and consuming the set of broadcasts routed through an origin.
Structs
- Consumer
- Cheap read handle over an origin’s broadcast tree.
- Dynamic
- Picks up
Consumer::request_broadcastcalls for paths that are not announced. - Info
- An origin’s identity plus the cache pool its broadcasts inherit.
- Producer
- Announces broadcasts to consumers over the network.
- Request
- A pending request for a broadcast that was not announced.
- Requesting
- The pollable result of
Consumer::request_broadcast.